@@ -24,7 +24,7 @@ import brave.Tracing;
 import org.apache.cxf.jaxrs.JAXRSServerFactoryBean;
 import org.apache.cxf.jaxrs.lifecycle.SingletonResourceProvider;
 import org.apache.cxf.jaxrs.model.AbstractResourceInfo;
-import org.apache.cxf.systest.brave.TestSpanReporter;
+import org.apache.cxf.systest.brave.TestSpanHandler;
 import org.apache.cxf.systest.brave.jaxrs.AbstractBraveTracingTest;
 import org.apache.cxf.systest.jaxrs.tracing.BookStore;
 import org.apache.cxf.systest.jaxrs.tracing.NullPointerExceptionMapper;
@@ -48,7 +48,7 @@ public class BraveTracingTest extends AbstractBraveTracingTest {
         protected void run() {
             final Tracing brave = Tracing
                     .newBuilder()
-                    .spanReporter(new TestSpanReporter())
+                    .addSpanHandler(new TestSpanHandler())
                     .build();
 
             final JAXRSServerFactoryBean sf = new JAXRSServerFactoryBean();
